@@ -1,10 +1,7 @@
 #!/bin/bash
 
-git submodule update --init
-
 if [ ! -d tor ]; then
-  echo "Tor directory not found!"
-  exit
+  git clone https://git.torproject.org/tor.git tor
 fi
 
 cd tor
